
# Slot: affects molecular modification of


holds between two molecular entities where the action or effect of one leads changes in the molecular modification(s) of the other (e.g. via post-translational modifications of proteins such as the addition of phosphoryl group, or via redox reaction that adds or subtracts electrons)

URI: [biolink:affects_molecular_modification_of](https://w3id.org/biolink/vocab/affects_molecular_modification_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [decreases molecular modification of](decreases_molecular_modification_of.md)
 *  [increases molecular modification of](increases_molecular_modification_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:affects_molecular_modification_of |
| **Narrow Mappings:** | | CTD:affects_acetylation |
|  | | CTD:affects_acylation |
|  | | CTD:affects_alkylation |
|  | | CTD:affects_amination |
|  | | CTD:affects_carbamoylation |
|  | | CTD:affects_ethylation |
|  | | CTD:affects_glutathionylation |
|  | | CTD:affects_glycation |
|  | | CTD:affects_glycosylation |
|  | | CTD:affects_glucuronidation |
|  | | CTD:affects_N-linked_glycosylation |
|  | | CTD:affects_O-linked_glycosylation |
|  | | CTD:affects_hydroxylation |
|  | | CTD:affects_lipidation |
|  | | CTD:affects_farnesylation |
|  | | CTD:affects_geranoylation |
|  | | CTD:affects_myristoylation |
|  | | CTD:affects_palmitoylation |
|  | | CTD:affects_prenylation |
|  | | CTD:affects_methylation |
|  | | CTD:affects_nitrosation |
|  | | CTD:affects_nucleotidylation |
|  | | CTD:affects_phosphorylation |
|  | | CTD:affects_ribosylation |
|  | | CTD:affects_ADP-ribosylation |
|  | | CTD:affects_sulfation |
|  | | CTD:affects_sumoylation |
|  | | CTD:affects_ubiquitination |
|  | | CTD:affects_oxidation |
|  | | CTD:affects_reduction |
|  | | CTD:affects_carboxylation |

